"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const audioconcat_1 = tslib_1.__importDefault(require("audioconcat"));
const log_1 = require("../utils/log");
const defaultPaths_1 = require("../config/defaultPaths");
class CreatePodcastAudioFile {
    constructor(content) {
        this.content = content;
    }
    async execute() {
        var _a;
        const audioFiles = (_a = this.content.renderData) === null || _a === void 0 ? void 0 : _a.map(data => data.audioFilePath);
        if (!audioFiles) {
            log_1.error('Failed to get audio files', 'CreatePodcastAudioFile');
            process.exit(1);
        }
        const transitionAudioPath = path_1.default.resolve(await defaultPaths_1.getPath('assets'), 'transition.mp3');
        const audioFilesWithTransitions = audioFiles
            .map((file, index) => {
            if (index === audioFiles.length - 1) {
                return [file];
            }
            return [file, transitionAudioPath];
        })
            .reduce((acc, array) => acc.concat(array), []);
        await this.concatAudioFiles(audioFilesWithTransitions);
    }
    concatAudioFiles(audioFilesPath) {
        return new Promise(async (resolve) => {
            audioconcat_1.default(audioFilesPath)
                .concat(path_1.default.resolve(await defaultPaths_1.getPath('tmp'), `${this.content.timestamp}.mp3`))
                .on('start', (command) => {
                log_1.log('Starting audios concatenation', 'CreatePodcastAudioFile', command);
            })
                .on('error', (err, stdout, stderr) => {
                log_1.error('Failed at concatenating audio', 'CreatePodcastAudioFile', JSON.stringify({ err, stdout, stderr }));
            })
                .on('end', (files) => {
                log_1.log('Audios concatenation finished', 'CreatePodcastAudioFile');
                resolve(files);
            });
        });
    }
}
exports.default = CreatePodcastAudioFile;
